from setuptools import setup, find_packages

setup(
    name="basics_operations_jm",  # Nome da biblioteca
    version="0.1.1",  # Versão
    packages=find_packages(),  # Descobre pacotes automaticamente
    install_requires=[],  # Dependências, se houver
    author="João Marcos",
    author_email="joaomarcospaulini@gmail.com",
    description="Uma biblioteca para operações básicas",
    url="https://github.com/JoaoMarcos91/operations",  # Opcional
)